==> darcs-2.14.2-70-x86_64.pkg.tar.xz: usr/share/haskell/register/darcs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: darcs
version: 2.14.2
id: darcs-2.14.2-HEKOQypkOUdCdSAPdMCGZC
key: darcs-2.14.2-HEKOQypkOUdCdSAPdMCGZC
license: GPL-2.0-only
maintainer: <darcs-devel@darcs.net>
author: David Roundy <droundy@darcs.net>, <darcs-devel@darcs.net>
stability: Experimental
homepage: http://darcs.net/
synopsis: a distributed, interactive, smart revision control system
description:
    Darcs is a free, open source revision control
    system. It is:
    .
    * Distributed: Every user has access to the full
    command set, removing boundaries between server and
    client or committer and non-committers.
    .
    * Interactive: Darcs is easy to learn and efficient to
    use because it asks you questions in response to
    simple commands, giving you choices in your work
    flow. You can choose to record one change in a file,
    while ignoring another. As you update from upstream,
    you can review each patch name, even the full "diff"
    for interesting patches.
    .
    * Smart: Originally developed by physicist David
    Roundy, darcs is based on a unique algebra of
    patches.
    .
    This smartness lets you respond to changing demands
    in ways that would otherwise not be possible. Learn
    more about spontaneous branches with darcs.
category: Development
abi: 0214b3d101937ea1f2d4292b95ee8e44
exposed: True
exposed-modules:
    Darcs.Patch Darcs.Patch.Annotate Darcs.Patch.Apply
    Darcs.Patch.ApplyMonad Darcs.Patch.ApplyPatches
    Darcs.Patch.Bracketed Darcs.Patch.Bracketed.Instances
    Darcs.Patch.Bundle Darcs.Patch.Choices Darcs.Patch.Commute
    Darcs.Patch.CommuteFn Darcs.Patch.Conflict Darcs.Patch.Debug
    Darcs.Patch.Depends Darcs.Patch.Dummy Darcs.Patch.Effect
    Darcs.Patch.FileHunk Darcs.Patch.Format Darcs.Patch.Index.Monad
    Darcs.Patch.Index.Types Darcs.Patch.Info Darcs.Patch.Inspect
    Darcs.Patch.Invert Darcs.Patch.Match Darcs.Patch.Matchable
    Darcs.Patch.Merge Darcs.Patch.MonadProgress Darcs.Patch.Named
    Darcs.Patch.Named.Wrapped Darcs.Patch.PatchInfoAnd
    Darcs.Patch.Permutations Darcs.Patch.Prim Darcs.Patch.Prim.Class
    Darcs.Patch.Prim.FileUUID Darcs.Patch.Prim.FileUUID.Apply
    Darcs.Patch.Prim.FileUUID.Coalesce
    Darcs.Patch.Prim.FileUUID.Commute Darcs.Patch.Prim.FileUUID.Core
    Darcs.Patch.Prim.FileUUID.Details
    Darcs.Patch.Prim.FileUUID.ObjectMap Darcs.Patch.Prim.FileUUID.Read
    Darcs.Patch.Prim.FileUUID.Show Darcs.Patch.Prim.V1
    Darcs.Patch.Prim.V1.Apply Darcs.Patch.Prim.V1.Coalesce
    Darcs.Patch.Prim.V1.Commute Darcs.Patch.Prim.V1.Core
    Darcs.Patch.Prim.V1.Details Darcs.Patch.Prim.V1.Read
    Darcs.Patch.Prim.V1.Show Darcs.Patch.Progress Darcs.Patch.Read
    Darcs.Patch.ReadMonads Darcs.Patch.Rebase
    Darcs.Patch.Rebase.Container Darcs.Patch.Rebase.Fixup
    Darcs.Patch.Rebase.Item Darcs.Patch.Rebase.Name
    Darcs.Patch.Rebase.Viewing Darcs.Patch.RegChars Darcs.Patch.Repair
    Darcs.Patch.RepoPatch Darcs.Patch.RepoType Darcs.Patch.Set
    Darcs.Patch.Show Darcs.Patch.Split Darcs.Patch.Summary
    Darcs.Patch.SummaryData Darcs.Patch.TokenReplace
    Darcs.Patch.TouchesFiles Darcs.Patch.Type Darcs.Patch.V1
    Darcs.Patch.V1.Apply Darcs.Patch.V1.Commute Darcs.Patch.V1.Core
    Darcs.Patch.V1.Prim Darcs.Patch.V1.Read Darcs.Patch.V1.Show
    Darcs.Patch.V1.Viewing Darcs.Patch.V2 Darcs.Patch.V2.Non
    Darcs.Patch.V2.Prim Darcs.Patch.V2.RepoPatch Darcs.Patch.Viewing
    Darcs.Patch.Witnesses.Eq Darcs.Patch.Witnesses.Ordered
    Darcs.Patch.Witnesses.Sealed Darcs.Patch.Witnesses.Show
    Darcs.Patch.Witnesses.Unsafe Darcs.Patch.Witnesses.WZipper
    Darcs.Prelude Darcs.Repository Darcs.Repository.ApplyPatches
    Darcs.Repository.Cache Darcs.Repository.Clone
    Darcs.Repository.Create Darcs.Repository.Diff
    Darcs.Repository.Flags Darcs.Repository.Format
    Darcs.Repository.Hashed Darcs.Repository.HashedIO
    Darcs.Repository.Identify Darcs.Repository.InternalTypes
    Darcs.Repository.Inventory Darcs.Repository.Job
    Darcs.Repository.Match Darcs.Repository.Merge Darcs.Repository.Old
    Darcs.Repository.Packs Darcs.Repository.PatchIndex
    Darcs.Repository.Pending Darcs.Repository.Prefs
    Darcs.Repository.Rebase Darcs.Repository.Repair
    Darcs.Repository.Resolution Darcs.Repository.State
    Darcs.Repository.Test Darcs.Repository.Working
    Darcs.UI.ApplyPatches Darcs.UI.Commands Darcs.UI.Commands.Add
    Darcs.UI.Commands.Amend Darcs.UI.Commands.Annotate
    Darcs.UI.Commands.Apply Darcs.UI.Commands.Clone
    Darcs.UI.Commands.Convert Darcs.UI.Commands.Diff
    Darcs.UI.Commands.Dist Darcs.UI.Commands.GZCRCs
    Darcs.UI.Commands.Help Darcs.UI.Commands.Init Darcs.UI.Commands.Log
    Darcs.UI.Commands.MarkConflicts Darcs.UI.Commands.Move
    Darcs.UI.Commands.Optimize Darcs.UI.Commands.Pull
    Darcs.UI.Commands.Push Darcs.UI.Commands.Rebase
    Darcs.UI.Commands.Record Darcs.UI.Commands.Remove
    Darcs.UI.Commands.Repair Darcs.UI.Commands.Replace
    Darcs.UI.Commands.Revert Darcs.UI.Commands.Rollback
    Darcs.UI.Commands.Send Darcs.UI.Commands.SetPref
    Darcs.UI.Commands.Show Darcs.UI.Commands.ShowAuthors
    Darcs.UI.Commands.ShowContents Darcs.UI.Commands.ShowDependencies
    Darcs.UI.Commands.ShowFiles Darcs.UI.Commands.ShowIndex
    Darcs.UI.Commands.ShowPatchIndex Darcs.UI.Commands.ShowRepo
    Darcs.UI.Commands.ShowTags Darcs.UI.Commands.Tag
    Darcs.UI.Commands.Test Darcs.UI.Commands.TransferMode
    Darcs.UI.Commands.Unrecord Darcs.UI.Commands.Unrevert
    Darcs.UI.Commands.Util Darcs.UI.Commands.Util.Tree
    Darcs.UI.Commands.WhatsNew Darcs.UI.CommandsAux Darcs.UI.Completion
    Darcs.UI.Defaults Darcs.UI.Email Darcs.UI.External Darcs.UI.Flags
    Darcs.UI.Options Darcs.UI.Options.All Darcs.UI.Options.Core
    Darcs.UI.Options.Flags Darcs.UI.Options.Iso
    Darcs.UI.Options.Markdown Darcs.UI.Options.Matching
    Darcs.UI.Options.Util Darcs.UI.PatchHeader Darcs.UI.PrintPatch
    Darcs.UI.RunCommand Darcs.UI.SelectChanges Darcs.UI.TheCommands
    Darcs.UI.Usage Darcs.Util.AtExit Darcs.Util.ByteString
    Darcs.Util.CommandLine Darcs.Util.Compat Darcs.Util.DateMatcher
    Darcs.Util.DateTime Darcs.Util.Diff Darcs.Util.Diff.Myers
    Darcs.Util.Diff.Patience Darcs.Util.Download
    Darcs.Util.Download.HTTP Darcs.Util.Download.Request
    Darcs.Util.Encoding Darcs.Util.English Darcs.Util.Exception
    Darcs.Util.Exec Darcs.Util.External Darcs.Util.File
    Darcs.Util.Global Darcs.Util.Hash Darcs.Util.Index
    Darcs.Util.IsoDate Darcs.Util.Lock Darcs.Util.Path
    Darcs.Util.Printer Darcs.Util.Printer.Color Darcs.Util.Progress
    Darcs.Util.Prompt Darcs.Util.Ratified Darcs.Util.Show
    Darcs.Util.SignalHandler Darcs.Util.Ssh Darcs.Util.Text
    Darcs.Util.Tree Darcs.Util.Tree.Hashed Darcs.Util.Tree.Monad
    Darcs.Util.Tree.Plain Darcs.Util.URL Darcs.Util.Workaround
hidden-modules: Version Darcs.Util.Download.Curl
import-dirs: /usr/lib/ghc-8.6.5/site-local/darcs-2.14.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/darcs-2.14.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/darcs-2.14.2
hs-libraries: HSdarcs-2.14.2-HEKOQypkOUdCdSAPdMCGZC
extra-libraries:
    curl
depends:
    HTTP-4000.3.13-2XvwvkdNO6a8Ksb7OpPRAJ array-0.5.3.0
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I binary-0.8.6.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptohash-0.11.9-7PRo03aB2Gz5H0SIVUcjNS
    data-ordlist-0.4.7.0-JijOptHq8X5AysaK6Liyhk directory-1.3.3.0
    fgl-5.7.0.1-9jDJi7QGXmIDO03XSi8vG5 filepath-1.4.2.1
    graphviz-2999.20.0.3-FEggVVn7T2rJfxreDwIQte
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo haskeline-0.7.4.3
    html-1.0.1.2-23NOv2EcnHy3biHspV2LAZ
    mmap-0.5.9-DPtA2NM6pwvChiGDibkbhO mtl-2.2.2
    network-2.8.0.0-KwUidTBebCCJ8Fjkxwovi
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    process-1.6.5.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    regex-applicative-0.3.3-LhNLVPHToDo5WPzFGWClqT
    regex-compat-tdfa-0.95.1.4-FPc13x8qI0cD1AJ9VEp5Jx
    sandi-0.5-JUwplmiG2zHL64uvxJP0Oq stm-2.5.0.0
    tar-0.5.1.0-GcqFpTqelp4Lmy6ZbjHbS7 terminfo-0.4.1.2 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    zip-archive-0.4.1-7KefGIUkXE84aOCGfiJiNs
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/darcs/html/darcs.haddock
haddock-html: /usr/share/doc/darcs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> darcs-2.14.2-77-x86_64.pkg.tar.xz: usr/share/haskell/register/darcs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: darcs
version: 2.14.2
id: darcs-2.14.2-7MUNXZ2zXXiARnGMejb8lZ
key: darcs-2.14.2-7MUNXZ2zXXiARnGMejb8lZ
license: GPL-2.0-only
maintainer: <darcs-devel@darcs.net>
author: David Roundy <droundy@darcs.net>, <darcs-devel@darcs.net>
stability: Experimental
homepage: http://darcs.net/
synopsis: a distributed, interactive, smart revision control system
description:
    Darcs is a free, open source revision control
    system. It is:
    .
    * Distributed: Every user has access to the full
    command set, removing boundaries between server and
    client or committer and non-committers.
    .
    * Interactive: Darcs is easy to learn and efficient to
    use because it asks you questions in response to
    simple commands, giving you choices in your work
    flow. You can choose to record one change in a file,
    while ignoring another. As you update from upstream,
    you can review each patch name, even the full "diff"
    for interesting patches.
    .
    * Smart: Originally developed by physicist David
    Roundy, darcs is based on a unique algebra of
    patches.
    .
    This smartness lets you respond to changing demands
    in ways that would otherwise not be possible. Learn
    more about spontaneous branches with darcs.
category: Development
abi: ee16e952f6209ad8ff4c91332a5c503b
exposed: True
exposed-modules:
    Darcs.Patch Darcs.Patch.Annotate Darcs.Patch.Apply
    Darcs.Patch.ApplyMonad Darcs.Patch.ApplyPatches
    Darcs.Patch.Bracketed Darcs.Patch.Bracketed.Instances
    Darcs.Patch.Bundle Darcs.Patch.Choices Darcs.Patch.Commute
    Darcs.Patch.CommuteFn Darcs.Patch.Conflict Darcs.Patch.Debug
    Darcs.Patch.Depends Darcs.Patch.Dummy Darcs.Patch.Effect
    Darcs.Patch.FileHunk Darcs.Patch.Format Darcs.Patch.Index.Monad
    Darcs.Patch.Index.Types Darcs.Patch.Info Darcs.Patch.Inspect
    Darcs.Patch.Invert Darcs.Patch.Match Darcs.Patch.Matchable
    Darcs.Patch.Merge Darcs.Patch.MonadProgress Darcs.Patch.Named
    Darcs.Patch.Named.Wrapped Darcs.Patch.PatchInfoAnd
    Darcs.Patch.Permutations Darcs.Patch.Prim Darcs.Patch.Prim.Class
    Darcs.Patch.Prim.FileUUID Darcs.Patch.Prim.FileUUID.Apply
    Darcs.Patch.Prim.FileUUID.Coalesce
    Darcs.Patch.Prim.FileUUID.Commute Darcs.Patch.Prim.FileUUID.Core
    Darcs.Patch.Prim.FileUUID.Details
    Darcs.Patch.Prim.FileUUID.ObjectMap Darcs.Patch.Prim.FileUUID.Read
    Darcs.Patch.Prim.FileUUID.Show Darcs.Patch.Prim.V1
    Darcs.Patch.Prim.V1.Apply Darcs.Patch.Prim.V1.Coalesce
    Darcs.Patch.Prim.V1.Commute Darcs.Patch.Prim.V1.Core
    Darcs.Patch.Prim.V1.Details Darcs.Patch.Prim.V1.Read
    Darcs.Patch.Prim.V1.Show Darcs.Patch.Progress Darcs.Patch.Read
    Darcs.Patch.ReadMonads Darcs.Patch.Rebase
    Darcs.Patch.Rebase.Container Darcs.Patch.Rebase.Fixup
    Darcs.Patch.Rebase.Item Darcs.Patch.Rebase.Name
    Darcs.Patch.Rebase.Viewing Darcs.Patch.RegChars Darcs.Patch.Repair
    Darcs.Patch.RepoPatch Darcs.Patch.RepoType Darcs.Patch.Set
    Darcs.Patch.Show Darcs.Patch.Split Darcs.Patch.Summary
    Darcs.Patch.SummaryData Darcs.Patch.TokenReplace
    Darcs.Patch.TouchesFiles Darcs.Patch.Type Darcs.Patch.V1
    Darcs.Patch.V1.Apply Darcs.Patch.V1.Commute Darcs.Patch.V1.Core
    Darcs.Patch.V1.Prim Darcs.Patch.V1.Read Darcs.Patch.V1.Show
    Darcs.Patch.V1.Viewing Darcs.Patch.V2 Darcs.Patch.V2.Non
    Darcs.Patch.V2.Prim Darcs.Patch.V2.RepoPatch Darcs.Patch.Viewing
    Darcs.Patch.Witnesses.Eq Darcs.Patch.Witnesses.Ordered
    Darcs.Patch.Witnesses.Sealed Darcs.Patch.Witnesses.Show
    Darcs.Patch.Witnesses.Unsafe Darcs.Patch.Witnesses.WZipper
    Darcs.Prelude Darcs.Repository Darcs.Repository.ApplyPatches
    Darcs.Repository.Cache Darcs.Repository.Clone
    Darcs.Repository.Create Darcs.Repository.Diff
    Darcs.Repository.Flags Darcs.Repository.Format
    Darcs.Repository.Hashed Darcs.Repository.HashedIO
    Darcs.Repository.Identify Darcs.Repository.InternalTypes
    Darcs.Repository.Inventory Darcs.Repository.Job
    Darcs.Repository.Match Darcs.Repository.Merge Darcs.Repository.Old
    Darcs.Repository.Packs Darcs.Repository.PatchIndex
    Darcs.Repository.Pending Darcs.Repository.Prefs
    Darcs.Repository.Rebase Darcs.Repository.Repair
    Darcs.Repository.Resolution Darcs.Repository.State
    Darcs.Repository.Test Darcs.Repository.Working
    Darcs.UI.ApplyPatches Darcs.UI.Commands Darcs.UI.Commands.Add
    Darcs.UI.Commands.Amend Darcs.UI.Commands.Annotate
    Darcs.UI.Commands.Apply Darcs.UI.Commands.Clone
    Darcs.UI.Commands.Convert Darcs.UI.Commands.Diff
    Darcs.UI.Commands.Dist Darcs.UI.Commands.GZCRCs
    Darcs.UI.Commands.Help Darcs.UI.Commands.Init Darcs.UI.Commands.Log
    Darcs.UI.Commands.MarkConflicts Darcs.UI.Commands.Move
    Darcs.UI.Commands.Optimize Darcs.UI.Commands.Pull
    Darcs.UI.Commands.Push Darcs.UI.Commands.Rebase
    Darcs.UI.Commands.Record Darcs.UI.Commands.Remove
    Darcs.UI.Commands.Repair Darcs.UI.Commands.Replace
    Darcs.UI.Commands.Revert Darcs.UI.Commands.Rollback
    Darcs.UI.Commands.Send Darcs.UI.Commands.SetPref
    Darcs.UI.Commands.Show Darcs.UI.Commands.ShowAuthors
    Darcs.UI.Commands.ShowContents Darcs.UI.Commands.ShowDependencies
    Darcs.UI.Commands.ShowFiles Darcs.UI.Commands.ShowIndex
    Darcs.UI.Commands.ShowPatchIndex Darcs.UI.Commands.ShowRepo
    Darcs.UI.Commands.ShowTags Darcs.UI.Commands.Tag
    Darcs.UI.Commands.Test Darcs.UI.Commands.TransferMode
    Darcs.UI.Commands.Unrecord Darcs.UI.Commands.Unrevert
    Darcs.UI.Commands.Util Darcs.UI.Commands.Util.Tree
    Darcs.UI.Commands.WhatsNew Darcs.UI.CommandsAux Darcs.UI.Completion
    Darcs.UI.Defaults Darcs.UI.Email Darcs.UI.External Darcs.UI.Flags
    Darcs.UI.Options Darcs.UI.Options.All Darcs.UI.Options.Core
    Darcs.UI.Options.Flags Darcs.UI.Options.Iso
    Darcs.UI.Options.Markdown Darcs.UI.Options.Matching
    Darcs.UI.Options.Util Darcs.UI.PatchHeader Darcs.UI.PrintPatch
    Darcs.UI.RunCommand Darcs.UI.SelectChanges Darcs.UI.TheCommands
    Darcs.UI.Usage Darcs.Util.AtExit Darcs.Util.ByteString
    Darcs.Util.CommandLine Darcs.Util.Compat Darcs.Util.DateMatcher
    Darcs.Util.DateTime Darcs.Util.Diff Darcs.Util.Diff.Myers
    Darcs.Util.Diff.Patience Darcs.Util.Download
    Darcs.Util.Download.HTTP Darcs.Util.Download.Request
    Darcs.Util.Encoding Darcs.Util.English Darcs.Util.Exception
    Darcs.Util.Exec Darcs.Util.External Darcs.Util.File
    Darcs.Util.Global Darcs.Util.Hash Darcs.Util.Index
    Darcs.Util.IsoDate Darcs.Util.Lock Darcs.Util.Path
    Darcs.Util.Printer Darcs.Util.Printer.Color Darcs.Util.Progress
    Darcs.Util.Prompt Darcs.Util.Ratified Darcs.Util.Show
    Darcs.Util.SignalHandler Darcs.Util.Ssh Darcs.Util.Text
    Darcs.Util.Tree Darcs.Util.Tree.Hashed Darcs.Util.Tree.Monad
    Darcs.Util.Tree.Plain Darcs.Util.URL Darcs.Util.Workaround
hidden-modules: Version Darcs.Util.Download.Curl
import-dirs: /usr/lib/ghc-8.6.5/site-local/darcs-2.14.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/darcs-2.14.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/darcs-2.14.2
hs-libraries: HSdarcs-2.14.2-7MUNXZ2zXXiARnGMejb8lZ
extra-libraries:
    curl
depends:
    HTTP-4000.3.14-Cz5w35CHL6jArVlsZGnuYL array-0.5.3.0
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I binary-0.8.6.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptohash-0.11.9-7PRo03aB2Gz5H0SIVUcjNS
    data-ordlist-0.4.7.0-JijOptHq8X5AysaK6Liyhk directory-1.3.3.0
    fgl-5.7.0.1-9jDJi7QGXmIDO03XSi8vG5 filepath-1.4.2.1
    graphviz-2999.20.0.3-FEggVVn7T2rJfxreDwIQte
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo haskeline-0.7.4.3
    html-1.0.1.2-23NOv2EcnHy3biHspV2LAZ
    mmap-0.5.9-DPtA2NM6pwvChiGDibkbhO mtl-2.2.2
    network-2.8.0.0-FZwMvc7MoUJBpGGHu2O13h
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    process-1.6.5.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    regex-applicative-0.3.3-LhNLVPHToDo5WPzFGWClqT
    regex-compat-tdfa-0.95.1.4-FPc13x8qI0cD1AJ9VEp5Jx
    sandi-0.5-376RC4yIT1WGDdnkxc9H0M stm-2.5.0.0
    tar-0.5.1.0-GcqFpTqelp4Lmy6ZbjHbS7 terminfo-0.4.1.2 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    zip-archive-0.4.1-7KefGIUkXE84aOCGfiJiNs
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/darcs/html/darcs.haddock
haddock-html: /usr/share/doc/darcs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
